"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.firestoreListParamsParser = exports.firestoreListOffsetParamsParser = exports.firestoreListLimitParamsParser = exports.queryOffsetLimitParser = exports.makeOffsetLimitParser = exports.makeOffsetParser = exports.makeLimitParser = exports.firestoreQueryOffsetParser = exports.queryOffsetParser = exports.firestoreQueryLimitParser = exports.queryLimitParser = void 0;
const zod_1 = require("zod");
const constants_1 = require("../../constants");
exports.queryLimitParser = zod_1.z
    .number()
    .int()
    .or(zod_1.z.string().regex(/^\d+$/).transform(Number))
    .refine((n) => n >= 0, {
    message: 'limit must be a positive number',
});
// for 'get' query params, .or shenanigans
exports.firestoreQueryLimitParser = exports.queryLimitParser.refine((n) => n <= constants_1.FIRESTORE_API_GET_LIMIT, {
    message: `limit must be less than ${constants_1.FIRESTORE_API_GET_LIMIT}`,
});
exports.queryOffsetParser = zod_1.z
    .number()
    .int()
    .or(zod_1.z.string().regex(/^\d+$/).transform(Number))
    .refine((n) => n >= 0, {
    message: 'offset must be a positive number',
});
// for 'get' query params, .or shenanigans
exports.firestoreQueryOffsetParser = exports.queryOffsetParser; // no special additions
const makeLimitParser = (parser) => zod_1.z.object({
    limit: parser,
});
exports.makeLimitParser = makeLimitParser;
const makeOffsetParser = (parser) => zod_1.z.object({
    offset: parser,
});
exports.makeOffsetParser = makeOffsetParser;
const makeOffsetLimitParser = (limitParser, offsetParser) => (0, exports.makeLimitParser)(offsetParser).merge((0, exports.makeOffsetParser)(limitParser));
exports.makeOffsetLimitParser = makeOffsetLimitParser;
exports.queryOffsetLimitParser = (0, exports.makeOffsetLimitParser)(exports.queryOffsetParser, exports.queryLimitParser);
const firestoreListLimitParser = exports.firestoreQueryLimitParser.optional().default(constants_1.FIRESTORE_API_GET_LIMIT);
const firestoreListOffsetParser = exports.firestoreQueryOffsetParser.optional().default(0);
exports.firestoreListLimitParamsParser = (0, exports.makeLimitParser)(firestoreListLimitParser);
exports.firestoreListOffsetParamsParser = (0, exports.makeOffsetParser)(firestoreListOffsetParser);
// TODO test that limit can't leak over 1000 or to -1
exports.firestoreListParamsParser = (0, exports.makeOffsetLimitParser)(firestoreListOffsetParser, firestoreListLimitParser);
